==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/WorkloadSelector.java <==

package me.snowdrop.istio.api.networking.v1alpha3;

import java.io.Serializable;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "labels"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class WorkloadSelector implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("labels")
    @JsonPropertyDescription("")
    private Map<String, String> labels;
    private final static long serialVersionUID = 7136020275022960764L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public WorkloadSelector() {
    }

    /**
     * 
     * @param labels
     */
    public WorkloadSelector(Map<String, String> labels) {
        super();
        this.labels = labels;
    }

    /**
     * 
     * 
     */
    @JsonProperty("labels")
    public Map<String, String> getLabels() {
        return labels;
    }

    /**
     * 
     * 
     */
    @JsonProperty("labels")
    public void setLabels(Map<String, String> labels) {
        this.labels = labels;
    }

}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/WorkloadSelector.java <==

package me.snowdrop.istio.api.networking.v1alpha3;

import java.io.Serializable;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "labels"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class)
})
public class WorkloadSelector implements Serializable
{

    /**
     * 
     */
    @JsonProperty("labels")
    @JsonPropertyDescription("")
    private Map<String, String> labels;
    private final static long serialVersionUID = 7136020275022960764L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public WorkloadSelector() {
    }

    /**
     * 
     * @param labels
     */
    public WorkloadSelector(Map<String, String> labels) {
        super();
        this.labels = labels;
    }

    /**
     * 
     */
    public Map<String, String> getLabels() {
        return labels;
    }

    /**
     * 
     */
    public void setLabels(Map<String, String> labels) {
        this.labels = labels;
    }

}
